@@ -42,31 +42,9 @@ class EmptyLine(MarkdownEntity):
     def __init__(self, content: str = ""):
         super().__init__(content, 'EmptyLine')
 
-class Paragraph(MarkdownEntity):
+class Text(MarkdownEntity):
     def __init__(self, content: str = ""):
-        super().__init__(content, 'Paragraph')
-
-class OrderList(MarkdownEntity):
-    def __init__(self, content: str = "", index: int = 1):
-        super().__init__(content, 'OrderList')
-        self.index = index
-
-class UnOrderList(MarkdownEntity):
-    def __init__(self, content: str = ""):
-        super().__init__(content, 'UnOrderList')
-
-class DisplayMath(MarkdownEntity):
-    def __init__(self, content: str = ""):
-        super().__init__(content, 'DisplayMath')
-
-class InlineLink(MarkdownEntity):
-    def __init__(self, content: str = "", url: str = ""):
-        super().__init__(content, 'InlineLink')
-        self.url = url
-
-class InlineMath(MarkdownEntity):
-    def __init__(self, content: str = ""):
-        super().__init__(content, 'InlineMath')
+        super().__init__(content, 'Text')
 
 class CompositeEntity(MarkdownEntity):
     def __init__(self, content: str = "", entity_type: str = ""):
@@ -86,7 +64,7 @@ class ListItem(CompositeEntity):
         inline_elements = parse_inline_elements(self.content)
         for elem in inline_elements:
             if isinstance(elem, str):
-                self.add_child(Paragraph(elem))
+                self.add_child(Text(elem))
             else:
                 self.add_child(elem)
 
@@ -101,6 +79,35 @@ class UnorderedListItem(ListItem):
         super().__init__(content, level)
         self.entity_type = 'UnorderedListItem'
 
+class DisplayMath(MarkdownEntity):
+    def __init__(self, content: str = ""):
+        super().__init__(content, 'DisplayMath')
+
+class InlineLink(MarkdownEntity):
+    def __init__(self, content: str = "", url: str = ""):
+        super().__init__(content, 'InlineLink')
+        self.url = url
+
+class InlineMath(MarkdownEntity):
+    def __init__(self, content: str = ""):
+        super().__init__(content, 'InlineMath')
+
+class Paragraph(CompositeEntity):
+    def __init__(self, content: str = ""):
+        super().__init__(content, 'Paragraph')
+        self.parse_content()
+
+    def parse_content(self):
+        inline_elements = parse_inline_elements(self.content)
+        for elem in inline_elements:
+            if isinstance(elem, str):
+                self.add_child(Text(elem))
+            else:
+                self.add_child(elem)
+
+    def __repr__(self):
+        return f'<Paragraph: {repr(self.children)}>'
+
 def parse_inline_elements(text):
     elements = []
     current_text = ""
@@ -109,7 +116,7 @@ def parse_inline_elements(text):
     while i < len(text):
         if text[i:i+2] == '$$':  # Display math
             if current_text:
-                elements.append(current_text)
+                elements.append(Text(current_text))
                 current_text = ""
             end = text.find('$$', i+2)
             if end != -1:
@@ -120,7 +127,7 @@ def parse_inline_elements(text):
                 break
         elif text[i] == '$':  # Inline math
             if current_text:
-                elements.append(current_text)
+                elements.append(Text(current_text))
                 current_text = ""
             end = text.find('$', i+1)
             if end != -1:
@@ -129,27 +136,42 @@ def parse_inline_elements(text):
             else:
                 current_text += text[i:]
                 break
-        elif text[i] == '[':  # Potential link
+        elif text[i] == '[':  # 潜在的链接
             if current_text:
-                elements.append(current_text)
+                elements.append(Text(current_text))
                 current_text = ""
-            link_end = text.find(')', i)
-            if link_end != -1 and '](' in text[i:link_end]:
-                content_end = text.index(']', i)
-                url_start = content_end + 2
-                content = text[i+1:content_end]
-                url = text[url_start:link_end]
-                elements.append(InlineLink(content, url))
-                i = link_end + 1
-            else:
-                current_text += text[i]
-                i += 1
+
+            # 查找匹配的右括号
+            bracket_count = 1
+            j = i + 1
+            while j < len(text) and bracket_count > 0:
+                if text[j] == '[':
+                    bracket_count += 1
+                elif text[j] == ']':
+                    bracket_count -= 1
+                j += 1
+
+            if j < len(text) and text[j] == '(':
+                # 找到了有效的链接格式
+                content_end = j - 1
+                url_start = j + 1
+                url_end = text.find(')', url_start)
+                if url_end != -1:
+                    content = text[i+1:content_end]
+                    url = text[url_start:url_end]
+                    elements.append(InlineLink(content, url))
+                    i = url_end + 1
+                    continue
+
+            # 如果不是有效的链接格式，将其作为普通文本处理
+            current_text += text[i]
+            i += 1
         else:
             current_text += text[i]
             i += 1
 
     if current_text:
-        elements.append(current_text)
+        elements.append(Text(current_text))
 
     return elements
 
@@ -159,11 +181,11 @@ def parse_markdown(lines, delimiter='\n'):
     current_math_block = []
     in_code_block = False
     in_math_block = False
-    language = None
-    list_stack = []
+    language = ""
+    # list_stack = []
 
     for line in lines:
-        # print(repr(line))
+        print(repr(line), line.startswith('```'), in_code_block)
         # print('[' in line)
         # print(']' in line )
         # print( '(' in line and ')' in line )
@@ -190,11 +212,11 @@ def parse_markdown(lines, delimiter='\n'):
             title_content = line[level:].strip()
             entities.append(TitleEntity(title_content, level))
         elif line.startswith('```'):
-            if in_code_block and language:
+            if in_code_block:
                 entities.append(CodeBlock('\n'.join(current_code_block), language))
                 current_code_block = []
                 in_code_block = False
-                language = None
+                language = ""
             else:
                 in_code_block = True
                 language = line.lstrip('`').strip()
@@ -224,8 +246,8 @@ def parse_markdown(lines, delimiter='\n'):
                 level = len(indent) // 2  # Assuming 2 spaces per indent level
 
                 # Clear list stack if we're at a lower or same level
-                while list_stack and list_stack[-1][0] >= level:
-                    list_stack.pop()
+                # while list_stack and list_stack[-1][0] >= level:
+                #     list_stack.pop()
 
                 if list_type in ['*', '-', '+']:
                     list_item = UnorderedListItem(content, level)
@@ -233,26 +255,24 @@ def parse_markdown(lines, delimiter='\n'):
                     index = int(list_type[:-1])
                     list_item = OrderedListItem(content, level, index)
 
-                if list_stack:
-                    list_stack[-1][1].add_child(list_item)
-                else:
-                    entities.append(list_item)
+                entities.append(list_item)
+                # if list_stack:
+                #     list_stack[-1][1].add_child(list_item)
+                # else:
+                #     entities.append(list_item)
 
-                list_stack.append((level, list_item))
+                # list_stack.append((level, list_item))
 
             elif line.strip():
-                # Handle other content (paragraphs, links, etc.)
+                # 处理其他内容(段落、链接等)
                 inline_elements = parse_inline_elements(line)
-                if len(inline_elements) == 1 and isinstance(inline_elements[0], str):
-                    entities.append(Paragraph(line))
-                else:
-                    para = CompositeEntity(line, 'Paragraph')
-                    for elem in inline_elements:
-                        if isinstance(elem, str):
-                            para.add_child(Paragraph(elem))
-                        else:
-                            para.add_child(elem)
-                    entities.append(para)
+                para = Paragraph()
+                for elem in inline_elements:
+                    if isinstance(elem, str):
+                        para.add_child(Text(elem))
+                    else:
+                        para.add_child(elem)
+                entities.append(para)
             else:
                 entities.append(EmptyLine(line))
 
@@ -262,20 +282,23 @@ def parse_markdown(lines, delimiter='\n'):
 
     return entities
 
-def convert_entity_to_text(entity, indent=''):
+def convert_entity_to_text(entity, indent='', linemode=False):
     if isinstance(entity, TitleEntity):
         return f"{'#' * entity.level} {entity.content}"
     elif isinstance(entity, CodeBlock):
         code = entity.content.lstrip('\n').rstrip('\n')
         return f"```{entity.language}\n{code}\n```"
-    # elif isinstance(entity, OrderedListItem):
-    #     content = convert_entities_to_text(entity.children, indent + '  ', inline=True) if entity.children else entity.content
-    #     return f"{indent}{entity.index}. {content}"
-    # elif isinstance(entity, UnorderedListItem):
-    #     content = convert_entities_to_text(entity.children, indent + '  ', inline=True) if entity.children else entity.content
-    #     return f"{indent}- {content}"
-    elif isinstance(entity, (OrderedListItem, UnorderedListItem)):
-        prefix = f"{indent}{entity.index}. " if isinstance(entity, OrderedListItem) else f"{indent}- "
+    elif isinstance(entity, OrderedListItem) and linemode:
+        # content = convert_entities_to_text(entity.children, indent + '  ', inline=True) if entity.children else entity.content
+        # return f"{indent}{entity.index}. {content}"
+        return f"{indent}{entity.index}. {entity.content}"
+    elif isinstance(entity, UnorderedListItem) and linemode:
+        # content = convert_entities_to_text(entity.children, indent + '  ', inline=True) if entity.children else entity.content
+        # return f"{indent}- {content}"
+        return f"{indent}- {entity.content}"
+    elif isinstance(entity, (OrderedListItem, UnorderedListItem)) and not linemode:
+        prefix = f"{entity.level * 2 * ' '}{entity.index}. " if isinstance(entity, OrderedListItem) else f"{entity.level * 2 * ' '}- "
+        # prefix = f"{indent}{entity.index}. " if isinstance(entity, OrderedListItem) else f"{indent}- "
         content = convert_entities_to_text(entity.children, inline=True)
         return f"{prefix}{content}"
     elif isinstance(entity, LinkEntity):
@@ -286,21 +309,27 @@ def convert_entity_to_text(entity, indent=''):
         return f"[{entity.content}]({entity.url})"
     elif isinstance(entity, EmptyLine):
         return f"{entity.content}"
-    elif isinstance(entity, Paragraph):
+    elif isinstance(entity, Text):
         return f"{entity.content}"
+    elif isinstance(entity, Paragraph):
+        return convert_entities_to_text(entity.children, inline=True)
     elif isinstance(entity, DisplayMath):
         return f"$$\n{entity.content}\n$$"
     elif isinstance(entity, InlineMath):
         return f"${entity.content}$"
     elif isinstance(entity, CompositeEntity):
-        return convert_entities_to_text(entity.children, indent, inline=True)
+        if linemode:
+            return entity.content
+        else:
+            return convert_entities_to_text(entity.children, indent, inline=True)
     else:
         return str(entity)
 
-def convert_entities_to_text(entities, indent='', inline=False):
+def convert_entities_to_text(entities, indent='', inline=False, linemode=False):
     result = []
     for index, entity in enumerate(entities):
-        converted = convert_entity_to_text(entity, indent)
+        # print("entity", entity)
+        converted = convert_entity_to_text(entity, indent, linemode=linemode)
         if inline:
             result.append(converted)
         elif index != len(entities) - 1 or (index == len(entities) - 1 and isinstance(entities[-1], EmptyLine)):
@@ -319,9 +348,9 @@ def save_text_to_file(text: str, file_path: str):
     with open(file_path, 'w', encoding='utf-8') as file:
         file.write(text)
 
-def process_markdown_entities_and_save(entities, file_path, raw_text=None):
+def process_markdown_entities_and_save(entities, file_path, raw_text=None, linemode=False):
     # Step 1: Convert entities to text
-    text_output = convert_entities_to_text(entities)
+    text_output = convert_entities_to_text(entities, linemode=linemode)
     if raw_text and raw_text != text_output:
         raise ValueError("The text output does not match the raw text input.")
     # Step 2: Save to file
@@ -370,7 +399,7 @@ def get_entities_from_markdown_file(file_path, delimiter='\n', raw_text=None):
     # 解析 Markdown 文档
     return parse_markdown(paragraphs, delimiter=delimiter)
 
-def check_markdown_parse(markdown_file_path, output_file_path="output.md", delimiter='\n'):
+def check_markdown_parse(markdown_file_path, output_file_path="output.md", delimiter='\n', debug=False):
     # 读取 Markdown 文件
     markdown_text = read_markdown_file(markdown_file_path)
 
@@ -379,7 +408,13 @@ def check_markdown_parse(markdown_file_path, output_file_path="output.md", delim
 
     # 解析 Markdown 文档
     parsed_entities = parse_markdown(paragraphs, delimiter=delimiter)
-    print(parsed_entities)
+    if debug:
+        # print(parsed_entities)
+        for entity in parsed_entities:
+            print(entity)
+            if hasattr(entity, 'children'):
+                for child in entity.children:
+                    print("child", child)
 
     # 将解析结果转换为文本
     converted_text = convert_entities_to_text(parsed_entities)
@@ -392,7 +427,27 @@ def check_markdown_parse(markdown_file_path, output_file_path="output.md", delim
 
     return parsed_entities
 
+def escape_code_block(content):
+    # 使用html.escape函数进行基本的HTML转义
+    import html
+    escaped_content = html.escape(content)
+
+    # 处理可能导致问题的其他特殊字符
+    escaped_content = escaped_content.replace('\n', '&#10;')  # 换行符
+    escaped_content = escaped_content.replace('\r', '&#13;')  # 回车符
+    escaped_content = escaped_content.replace('\t', '&#9;')   # 制表符
+    escaped_content = escaped_content.replace(' ', '&#32;')   # 空格
+    escaped_content = escaped_content.replace('`', '&#96;')   # 反引号
+    escaped_content = escaped_content.replace('$', '&#36;')   # 美元符号（可能与数学公式冲突）
+
+    # 处理EOF和其他控制字符
+    escaped_content = ''.join('&#%d;' % ord(c) if ord(c) < 32 or ord(c) == 127 else c for c in escaped_content)
+
+    return escaped_content
+
 def convert_entities_to_xue(entities):
+    for entity in entities:
+        print(entity)
     def process_entity(entity):
         if isinstance(entity, TitleEntity):
             header_tag = globals()[f'H{entity.level}']
@@ -404,14 +459,15 @@ def convert_entities_to_xue(entities):
                 5: "text-lg",
                 6: "text-base"
             }.get(entity.level, "text-base")
-            return header_tag(entity.content, class_=f"font-bold mb-4 text-gray-800 dark:text-gray-200 {size_class}")
+            return header_tag(entity.content, class_=f"font-bold mt-4 mb-4 text-gray-800 dark:text-gray-200 {size_class}")
 
         elif isinstance(entity, CodeBlock):
+            escaped_content = escape_code_block(entity.content)
             code_block = Pre(
-                Code(entity.content, class_=f"language-{entity.language}"),
+                Code(escaped_content, class_=f"language-{entity.language}"),
                 class_="bg-gray-100 dark:bg-gray-800 rounded-lg p-4 overflow-x-auto"
             )
-            return Div(code_block, class_="code-block-wrapper")
+            return Div(code_block, class_="code-block-wrapper mt-4")
 
         # elif isinstance(entity, ListItem):
         #     print("entity", entity)
@@ -420,21 +476,30 @@ def convert_entities_to_xue(entities):
         #     return Li(process_children(entity.children) if hasattr(entity, 'children') else entity.content, class_="mb-2")
 
         elif isinstance(entity, LinkEntity) or isinstance(entity, InlineLink):
-            return A(entity.content, href=entity.url, class_="mr-2 text-primary-light dark:text-primary-dark hover:underline")
+            return A(entity.content, href=entity.url, class_="mr-0 text-primary-light dark:text-primary-dark hover:underline")
 
         elif isinstance(entity, EmptyLine):
             return None
 
         elif isinstance(entity, OrderedListItem):
             content = process_children(entity.children) if hasattr(entity, 'children') else [entity.content]
-            return Ol(Li(*content, class_="mb-2"), start=entity.index, class_="list-decimal list-inside mb-4")
+            return Ol(Li(*content, class_="mb-0"), start=entity.index, class_="list-decimal mb-1 ml-4")
+            # return Ol(Li(*content, class_="mb-2"), start=entity.index, class_="list-decimal list-inside mb-4")
+            # return Ol(Li(Div(*content, class_ = "flex items-center"), class_="mb-0"), class_="list-decimal mb-0 ml-4")
 
         elif isinstance(entity, UnorderedListItem):
+            # print("UnorderedListItem", hasattr(entity, 'children'))
             content = process_children(entity.children) if hasattr(entity, 'children') else [entity.content]
-            return Ul(Li(Div(*content, class_ = "flex items-center"), class_="mb-0"), class_="list-disc list-inside mb-0")
+            # return Ul(Li(*content, class_="mb-0"), class_="list-disc list-inside mb-0")
+            # return Ul(Li(Div(*content, class_ = "flex items-center"), class_="mb-0"), class_="list-disc mb-0 ml-4")
+            return Ul(Li(*content, class_="mb-0"), class_="list-disc mb-1 ml-4")
+            # return Ul(Li(Div(*content, class_ = "flex flex-wrap"), class_="mb-0"), class_="list-disc mb-0 ml-4")
 
         elif isinstance(entity, Paragraph):
-            return P(process_inline_elements(entity.content), class_="mr-2")
+            content = process_children(entity.children) if hasattr(entity, 'children') else [entity.content]
+            # return Span(process_inline_elements(entity.content), class_="mr-2 flex-shrink-0")
+            # return P(process_inline_elements(entity.content), class_="mr-2 mb-0")
+            return P(*content, class_="mr-0 mb-1")
 
         elif isinstance(entity, ImageEntity):
             return Image(src=entity.content, alt=entity.alt_text, class_="max-w-full h-auto rounded-lg shadow-lg mb-4")
@@ -446,13 +511,29 @@ def convert_entities_to_xue(entities):
             return Span(entity.content, class_="math-inline")
 
         elif isinstance(entity, CompositeEntity):
-            return Div(*[process_entity(child) for child in entity.children], class_="composite-entity flex items-center mb-0")
+            return Div(*[process_entity(child) for child in entity.children], class_="composite-entity flex items-center mb-2")
 
         else:
-            return str(entity)
+            return str(entity.content)
 
     def process_children(children):
-        return [Span(process_entity(child), class_="mr-2 flex-shrink-0") for child in children if child is not None if process_entity(child) is not None]
+        # result = []
+        # for child in children:
+        #     if child is not None:
+        #         item = process_entity(child)
+        #         if item is not None:
+        #             if isinstance(item, (Div, Span, H1, H2, H3, H4, H5, H6)):
+        #                 result.append(item)
+        #             else:
+        #                 result.append(Span(item, class_="mr-2 flex-shrink-0"))
+        # return result
+        for child in children:
+            print("child", child)
+
+        return [process_entity(child) for child in children if child is not None if process_entity(child) is not None]
+        # return [Span(process_entity(child), class_="mr-2 w-full") for child in children if child is not None if process_entity(child) is not None]
+        # return [Span(process_entity(child), class_="mr-2 flex-shrink-0") for child in children if child is not None if process_entity(child) is not None]
+        # return [process_entity(child) for child in children if child is not None if process_entity(child) is not None]
 
     def process_inline_elements(content):
         # 这里可以添加处理行内元素的逻辑，比如链接、行内数学公式等
